changed_paths

Function changed_paths 

pub fn changed_paths(
    repo: &Path,
    from: &str,
    to: &str,
) -> Result<Vec<String>, String>
Paths where to differs from from.

NUL-separated, because a repository is free to contain a path with a newline in it and --name-only alone would quote it.

Errors

Git failing to run, or exiting nonzero.